Package 'hipercow.dide'

Title: HPC Support for the DIDE cluster
Description: Drivers for using the DIDE cluster on windows and linux compute nodes, via the hipercow package. Typically the user will install that package directly and this once they are requested to.
Authors: Rich FitzJohn [aut, cre], Wes Hinsley [aut], Paul Lietar [aut], Imperial College of Science, Technology and Medicine [cph]
Maintainer: Rich FitzJohn <[email protected]>
License: MIT + file LICENSE
Version: 1.1.8
Built: 2026-05-25 07:55:24 UTC
Source: https://github.com/mrc-ide/hipercow

Help Index